@@ -82,7 +82,7 @@ class Worker(Thread):
                     try:
                         res = func(*args, **kargs)
 
-                        if res["cache"] is not None:
+                        if res is not None and res["cache"] is not None:
                             hash = hashlib.sha256(res["cache"].encode("utf-8")).digest()
                             for i in range(len(self.cache_accum)):
                                 self.cache_accum[i] ^= hash[i]
@@ -288,6 +288,7 @@ class LatchPersistence(DataPersistence):
             try:
                 from latch_cli.services.cp import cp
 
+                # todo(ayush) cache version ids
                 cp(file_path, to_path)
             except Exception as e:
                 raise FlyteUserException("failed to get presigned upload urls for `{}`".format(to_path)) from e
