@@ -319,7 +319,12 @@ class FlyteFilePathTransformer(TypeTransformer[FlyteFile]):
             raise TypeTransformerFailedError(f"Expected FlyteFile or os.PathLike object, received {type(python_val)}")
 
         # Don't upload by default in local execution
-        if remote_path is None and ctx.execution_state.mode == ExecutionState.Mode.LOCAL_WORKFLOW_EXECUTION:
+        if (
+            remote_path is None
+            and hasattr(ctx, "execution_state")
+            and ctx.execution_state is not None
+            and ctx.execution_state.mode == ExecutionState.Mode.LOCAL_WORKFLOW_EXECUTION
+        ):
             should_upload = False
 
         # If we're uploading something, that means that the uri should always point to the upload destination.
